@@ -3,9 +3,7 @@ from handler.handler_helper import Handler
 from handler.flow_data import FlowDataException
 from kubernetes import client, config
 from kubernetes.client.rest import ApiException
-import socket
 import os
-import json
 
 application = Flask(__name__)
 global_workflows = {}
@@ -13,7 +11,6 @@ global_workflows = {}
 config.load_kube_config()
 api_instance = client.VersionApi()
 
-
 class App:
 
     def __init__(self):
@@ -95,18 +92,14 @@ class App:
 
     @staticmethod
     def start():
-        port = select_port()
-        print("select_port")
-        print(port)
-        write_port_to_file(port)
         try:
             debug = os.getenv("DEBUG")
             if debug == "true":
                 application.config["DEBUG"] = True
                 application.config["ENV"] = "development"
-                application.run(host='localhost', port=port)
+                application.run(host='localhost', port='8080')
             else:
-                application.run(host="localhost", port=port)
+                application.run(host="localhost", port='8080')
 
         except ExecutorException as e:
             raise ExecutorException(status=e.status, reason=e.reason)
@@ -119,38 +112,6 @@ def create_app():
     return App()
 
 
-def is_port_in_use(port):
-    try:
-        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
-            return s.connect_ex(('localhost', port)) == 0
-    except Exception as e:
-        print(e)
-        raise ExecutorException(status=0, reason="Failed to check available Port")
-
-
-def select_port():
-    port = 9000
-    while True:
-        if is_port_in_use(port):
-            port += 1
-            if port > 9100:
-                raise ExecutorException(status=0, reason="Failed to find available Port between 9000 and 9100")
-        else:
-            break
-    return port
-
-
-# todo change to working dir when deploy
-def write_port_to_file(port):
-    with open('/application/.runtime/status.json', 'r') as json_file:
-        data = json.load(json_file)
-        print("write_port_to_file")
-        print(str(port))
-        data["python-executor"]["port"] = str(port)
-    with open('/application/.runtime/status.json', 'w') as output_file:
-        json.dump(data, output_file)
-
-
 class ExecutorException(Exception):
 
     def __init__(self, status=None, reason=None):
